pub unsafe fn utf8_cstr_bounds<'a>(
start: *const c_char,
end: *const c_char,
) -> &'a strExpand description
Gets a known-to-be valid UTF-8 string given start/end-exclusive pointers to its bounds.
Safety: start must be a valid pointer, and end must be the same for a zero-length string,
or greater than start. All the bytes between them must be valid UTF-8.